---
title: Info
---

# Show information about the workflow

The `info` subcommand provides JSON formatted information about the workflow.

```bash
snk-basic-pipeline info
```
```json
{
  "name": "snk-basic-pipeline",
  "version": "4a530896",
  "workflow_dir_path": ".../snk/workflows/snk-basic-pipeline"
}
```